<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>Objekt wählen：</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>SO:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Maßstab</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>Global:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>Beibehalten:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Scheren</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Mitte</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">Lock</translation>
    </message>
    <message>
        <source>(</source>
        <translation>(</translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Mittlere Position</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">[Dicke]</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">Härte:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">Genauigkeit:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">Selektiv</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">Vorlage:</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">Scharfe Winkel brechen</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">Bleistift Modus</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Druckempfindlichkeit</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">Cap</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">Vereinen</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">Gehrung:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">Größe</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">Scharfe Winkel brechen</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="vanished">Bleistift Modus</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">Druck</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="obsolete">Einrasten</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation>Name der Vorlage</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>Zeichnung automatisch wählen</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Einrasten</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Typ:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>Linearen Kontrollpunkt setzen</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>Nicht-Linearen Kontrollpunkt setzen</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>Maßstab-Beschränkung</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>Spalte automatisch wählen</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Globale Taste</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>Mitte [X] sperren</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>Mitte ［Y］ sperren</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>Position ［X］ sperren</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>Position ［Y］ sperren</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>Rotation sperren</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>Scherung H sperren</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>Scherung V sperren</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>Maßstab H sperren</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>Maßstab V sperren</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>Globalen Maßstab sperren</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>X- und Y-Positionen</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Z Position</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>Globalen Maßstab sperren</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>Horizontaler und vertikaler Maßstab</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Scheren</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Mittlere Position</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation>Aktive Achse</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Position</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Maßstab</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished">Mitte</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Härte:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selektiv</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertieren</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Frame-Bereich</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Bleistift Modus</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Segment</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>Frame-Reichweite</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selektiv</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>Onion Skin</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>Fülltiefe</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segment</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick+Freehand</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertieren</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Dicke</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Druckempfindlichkeit</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">Opazität:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Härte:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Vorlage:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished">Größe</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished">Druck</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opazität:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Härte:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertieren</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Frame-Bereich</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation type="unfinished">Fülltiefe</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>Einrasten</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selektiv</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>Ecke:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>Skelett aufbauen</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>Starr malen</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>Animieren</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>Starr</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>Flexibel</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>Vertex-Name:</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>Strecken erlauben</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>Abstand beibehalten</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Globale Taste</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>Eine Gruppe Skelette existiert bereits für die aktuelle Spalte. Sie zu ersetzen, wird jegliche vorhandenen Vertex-Animationen austauschen.

Möchten Sie fortfahren?</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>Skelett kopieren</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>Skelett einfügen</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>Vertex löschen</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Taste setzen</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>Ruhepositions-Key setzen</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>Globale Taste setzen</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>Globale Rast-Taste setzen</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>Mesh zeigen</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>Starrheit zeigen</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>SO zeigen</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>Skelett Onion Skin zeigen</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>Der vorherige Vertex-Name wird verworfen und alle zugewiesenen Tasten gehen verloren.

Möchten Sie fortfahren?</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>Mesh bearbeiten</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>An Mesh einrasten</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>Winkelbegrenzung</translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation>Kanten tauschen</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>Kante löschen</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>Kante teilen</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>Mesh schneiden</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>Mesh erstellen</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>Skelett</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Abstand</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>Form:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>Dicke：</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opazität:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Härte:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>Polygon-Seiten:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>Automatisches Gruppieren</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>Automatisches Füllen</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selektiv</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Bleistift Modus</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Vereinen</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Gehrung:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Einrasten</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation type="unfinished">Glätten</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Genauigkeit:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>Minimum:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>Maximum:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>Die kopierte Auswahl kann nicht in die aktuelle Zeichnung eingefügt werden.</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>Die aktuelle Spalte ist gesperrt.</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">Die aktuelle Spalte ist nicht sichtbar im Kamera-Stand.</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>Es ist nicht möglich die Audio-Spalte zu bearbeiten.</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">Es ist nicht möglich die Magpie-Spalte zu bearbeiten.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>Das aktuelle Werkzeug kann nicht mit einer Level-Spalte angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>Das aktuelle Werkzeug kann nicht mit einer Mesh-Spalte angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>Das aktuelle Werkzeug kann nicht im Level Strip Modus angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>Das aktuelle Werkzeug kann nicht zum Bearbeiten eines Bewegungspfads angewendet werden.</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>Die aktuelle Ebene ist nicht bearbeitbar.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>Das aktuelle Werkzeug kann nicht auf einer Vektor-Ebene angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>Das aktuelle Werkzeug kann nicht auf einer Toonz-Ebene angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>Das aktuelle Werkzeug kann nicht auf einer Raster-Ebene angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>Das aktuelle Werkzeug kann nicht auf einer Mesh-Ebene angewendet werden.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>Das aktuelle Werkzeug kann nicht auf einer Mesh-verformten-Ebene angewendet werden.</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>Der aktuelle Frame ist gesperrt: jegliches Bearbeiten ist verboten.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation>Mittlere Position bewegen</translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>RGB Wähler (R%1, G%2, B%3)</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppieren</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Gruppe auflösen</translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation>Gruppe bewegen</translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation>Effekt-Gadget modifizieren</translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1   Ebene : %2  Frame : %3</translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation>Kontur-Werkzeug modifizieren</translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation>Spline modifizieren</translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation>Raster verformen</translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation>Raster transformieren</translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>Speicher-Box setzen : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>Passives Wählen</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>Bildschirm wählen</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>No Antialiasing</source>
        <translation>Keine Kantenglättung</translation>
    </message>
    <message>
        <source>Modify Savebox</source>
        <translation>Speicher-Box modifizieren</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>Abstand：</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>Stil-Index:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opazität:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Frame-Reichweite</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>Winkel：</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">H:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Seitenverhältnis festlegen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Maßstab</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Position</translation>
    </message>
    <message>
        <source>Flip Selection Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Selection Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Global Key</source>
        <translation>Globale Taste</translation>
    </message>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>Nur aktives Skelett anzeigen</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>Festgesetzte Mitte zurücksetzen</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation type="unfinished">Skelett aufbauen</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation type="unfinished">Animieren</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation type="unfinished">Modus:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation type="unfinished">Passives Wählen</translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation type="unfinished">Größe</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="unfinished">Härte:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="unfinished">Glätten:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="unfinished">Vorlage:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished">Bleistift Modus</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished">Druck</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Genauigkeit:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>Glätten:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Vorlage:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Break</source>
        <translation>Scharfe Winkel brechen</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Druck</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Vereinen</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Gehrung:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>Einrasten</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>Vertikale Ausrichtung</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>Dicke beibehalten</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Vereinen</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Gehrung:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>Glätten</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>Vektoren verbinden</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modus:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
